==> byteplus_rtc-3.44.1.tar.gz: lib/api/bytertc_event_define.dart <==
// Copyright 2022 BytePlus Pte. Ltd.
// SPDX-License-Identifier: MIT

import 'dart:typed_data';

import 'package:flutter/foundation.dart';

import 'bytertc_audio_defines.dart';
import 'bytertc_common_defines.dart';
import 'bytertc_video_defines.dart';

typedef EmptyCallbackType = void Function();

/// [code]: Warning code.
typedef OnWarningType = void Function(WarningCode code);

/// [code]: Error code.
typedef OnErrorType = void Function(ErrorCode code);

/// [roomId]: The ID of the room where the error occurred.
///
/// [errorCode]: Possible errors when creating a room.
typedef OnCreateRoomStateChangedType = void Function(
    String roomId, int errorCode);

/// [state]: Current connection status between SDK and signaling server.
typedef OnConnectionStateChanged = void Function(RTCConnectionState state);

/// [streamIndex]: Stream type.
///
/// [videoFrameInfo]: Video information.
typedef OnFirstLocalVideoFrameCapturedType = void Function(
    StreamIndex streamIndex, VideoFrameInfo videoFrameInfo);

/// [index]: Type of the audio stream.
typedef OnFirstLocalAudioFrameType = void Function(StreamIndex index);

/// [streamKey]: Information about the remote audio stream.
typedef OnFirstRemoteAudioFrameType = void Function(RemoteStreamKey streamKey);

/// [streamKey]: Information about the remote stream.
///
/// [videoFrameInfo]: Information about the video frame.
typedef OnFirstRemoteVideoFrameRenderedType = void Function(
    RemoteStreamKey streamKey, VideoFrameInfo videoFrameInfo);

/// [roomId]: The ID of the room where the remote user who enables/disables media capturing is in.
///
/// [uid]: The ID of the remote user who enables/disables media capturing.
typedef OnUserOperateMediaCaptureType = void Function(
    String roomId, String uid);

/// [audioPropertiesInfos]: Local audio information.
typedef OnLocalAudioPropertiesReportType = void Function(
    List<LocalAudioPropertiesInfo> audioPropertiesInfos);

/// [audioPropertiesInfos]: Remote audio information.
///
/// [totalRemoteVolume]: Total volume of all subscribed remote streams.
typedef OnRemoteAudioPropertiesReportType = void Function(
    List<RemoteAudioPropertiesInfo> audioPropertiesInfos,
    int totalRemoteVolume);

/// [mixId]: Audio mixing task ID.
///
/// [state]: Mixing status.
///
/// [error]: Mixing related error code.
typedef OnAudioMixingStateChangedType = void Function(
    int mixId, AudioMixingState state, AudioMixingError error);

/// [mixId]: Audio mixing task ID.
///
/// [progress]: The current playback progress of the mixed audio file, in milliseconds.
typedef OnAudioMixingPlayingProgressType = void Function(
    int mixId, int progress);

/// [type]: Current network connection type.
typedef OnNetworkTypeChangedType = void Function(NetworkType type);

/// [streamKey]: Including the SEI sender's username, room name and media stream.
///
/// [message]: Content of the SEI message received.
typedef OnSEIMessageReceivedType = void Function(
    RemoteStreamKey streamKey, Uint8List message);

/// [streamKey]: Remote stream information.
///
/// [event]: Status of the black frame video stream.
typedef OnSEIStreamUpdateType = void Function(
    RemoteStreamKey streamKey, SEIStreamUpdateEvent event);

/// [streamKey]: Remote stream information.
///
/// [streamType]: Media stream type.
///
/// [data]: Message content.
typedef OnStreamSyncInfoReceivedType = void Function(
    RemoteStreamKey streamKey, SyncInfoStreamType streamType, Uint8List data);

/// [mode]: Indicates whether publish fallback is enabled locally.
///
/// [roomId]: When publish performance fallback is disabled, roomId is empty. When publish performance fallback is enabled, roomId is the ID of the room affected by the alert.
///
/// [reason]: Reasons for the warning.
///
/// [data]: Performance fallback related data
typedef OnPerformanceAlarmsType = void Function(PerformanceAlarmMode mode,
    String roomId, PerformanceAlarmReason reason, SourceWantedData data);

/// [event]: Information on changes in audio and video streams.
typedef OnSimulcastSubscribeFallbackType = void Function(
    RemoteStreamSwitch event);

/// [state]: Current HTTP proxy connection status.
typedef OnHttpProxyStateType = void Function(int state);

/// [state]: Current HTTPS proxy connection status.
typedef OnHttpsProxyStateType = void Function(int state);

/// [state]: Current SOCKS5 proxy connection status.
typedef OnSocks5ProxyStateType = void Function(int state, String cmd,
    String proxyAddress, String localAddress, String remoteAddress);

/// [type]: Types of recorded streams.
///
/// [state]: Recording status.
///
/// [errorCode]: Recording error code.
///
/// [info]: Details of the recorded file.
typedef OnRecordingStateUpdateType = void Function(StreamIndex type,
    RecordingState state, RecordingErrorCode errorCode, RecordingInfo info);

/// [type]: Types of recorded streams.
///
/// [progress]: Recording progress.
///
/// [info]: Details of the recorded file.
typedef OnRecordingProgressUpdateType = void Function(
    StreamIndex type, RecordingProgress progress, RecordingInfo info);

/// [stats]: CPU and memory information.
typedef OnSysStatsType = void Function(SysStats stats);

/// [stats]: Summary statistics in the room.
typedef OnRoomStatsType = void Function(RTCRoomStats stats);

/// [stats]: Media stream and network status statistics
typedef OnLocalStreamStatsType = void Function(LocalStreamStats stats);

/// [stats]: Media stream and network status statistics
typedef OnRemoteStreamStatsType = void Function(RemoteStreamStats stats);

/// [roomId]: ID of the room where the status change occured.
///
/// [uid]: ID of the user whose status has changed.
///
/// [state]: Room status code:
/// + 0: Success
/// + !0: Failure, see [ErrorCode] and [WarningCode] for details.
///
/// [extraInfo]: Extra information.
/// + `joinType`: `0` represents joining in the room for the first time, `1` represents a reconnection into the room.
/// + `elapsed`: The time interval (in ms) between the local user calling [RTCRoom.joinRoom] and successfully entering the room.
typedef OnRoomStateChangedType = void Function(
    String roomId, String uid, int state, String extraInfo);

/// [stats]: Statistics of this call.
typedef OnLeaveRoomType = void Function(RTCRoomStats stats);

/// [userInfo]: User information.
///
/// [elapsed]: The time in ms between the visible user calling [RTCRoom.joinRoom] to join the room and other users in the room receiving this event.
typedef OnUserJoinedType = void Function(UserInfo userInfo, int elapsed);

/// [uid]: ID of the remote user who left the room or switched to invisible.
///
/// [reason]: Reasons why remote users leave.
typedef OnUserLeaveType = void Function(String uid, UserOfflineReason reason);

/// [eventType]: Task status.
///
/// [taskId]: Task ID.
///
/// [error]: Errors occuring when pushing stream to CDN.
///
/// [mixType]: Task type.
typedef OnStreamMixingEventType = void Function(StreamMixingEvent eventType,
    String taskId, TranscoderErrorCode error, StreamMixingType mixType);

/// [roomId]: ID of the room from which the stream is published.
///
/// [userInfo]: User information.
///
/// [state]: First frame sent status.
typedef OnMediaFrameSendStateChangedType = void Function(
    String roomId, UserInfo userInfo, FirstFrameSendState state);

/// [roomId]: ID of the room which the stream publisher is in.
///
/// [userInfo]: User information.
///
/// [state]: First frame playback status.
typedef OnMediaFramePlayStateChangedType = void Function(
    String roomId, UserInfo userInfo, FirstFramePlayState state);

/// [streamIndex]: Stream type.
///
/// [videoFrameInfo]: Video frame information.
typedef OnLocalVideoSizeChangedType = void Function(
    StreamIndex streamIndex, VideoFrameInfo videoFrameInfo);

/// [streamKey]: Remote stream information.
///
/// [videoFrameInfo]: Video frame information.
typedef OnRemoteVideoSizeChangedType = void Function(
    RemoteStreamKey streamKey, VideoFrameInfo videoFrameInfo);

/// [state]: Status of local audio device.
///
/// [error]: Error code when the state of the local audio stream changes.
typedef OnLocalAudioStateChangedType = void Function(
    LocalAudioStreamState state, LocalAudioStreamError error);

/// [streamKey]: Remote stream information.
///
/// [state]: Remote audio stream status.
///
/// [reason]: Reasons for change in remote audio stream status.
typedef OnRemoteAudioStateChangedType = void Function(RemoteStreamKey streamKey,
    RemoteAudioState state, RemoteAudioStateChangeReason reason);

/// [index]: Stream type.
///
/// [state]: Local video stream status.
///
/// [error]: Error code when local video status changes.
typedef OnLocalVideoStateChangedType = void Function(StreamIndex index,
    LocalVideoStreamState state, LocalVideoStreamError error);

/// [streamKey]: Information about the remote video stream.
///
/// [state]: Remote video stream status.
///
/// [reason]: The reason for the change in the status of the remote video stream.
typedef OnRemoteVideoStateChangedType = void Function(RemoteStreamKey streamKey,
    RemoteVideoState state, RemoteVideoStateChangedReason reason);

/// [uid]: ID of the logged-in user.
///
/// [errorCode]: Login result.
///
/// [elapsed]: The time taken from calling [RTCVideo.login] to the result being returned.
typedef OnLoginResultType = void Function(
    String uid, LoginErrorCode errorCode, int elapsed);

/// [error]: Setting result
/// + 200: Success.
/// + Others: Failure, see [UserMessageSendResult] for details.
typedef OnServerParamsSetResultType = void Function(int error);

/// [peerUid]: ID of the user to be queried.
///
/// [status]: Login status of the queried user.
typedef OnGetPeerOnlineStatusType = void Function(
    String peerUid, UserOnlineStatus status);

/// [msgid]: ID of this message.
///
/// [error]: Text or binary message sending results.
typedef OnMessageSendResultType = void Function(
    int msgid, UserMessageSendResult error);

/// [msgid]: ID of this message.
///
/// [error]: Text or binary message sending results.
typedef OnRoomMessageSendResultType = void Function(
    int msgid, RoomMessageSendResult error);

/// [msgid]: ID of this message.
///
/// [error]: Sending result.
///
/// [message]: Information returned by the application server in the ACK after receiving an HTTP request.
typedef OnServerMessageSendResultType = void Function(
    int msgid, UserMessageSendResult error, Uint8List message);

/// [uid]: ID of the user who send the message.
///
/// [message]: Contents of the received message.
typedef OnMessageReceivedType = void Function(String uid, String message);

/// [uid]: ID of the user who send the message. ID
///
/// [message]: Contents of the received message.
typedef OnBinaryMessageReceivedType = void Function(
    String uid, Uint8List message);

/// [uid]: ID of the user of whom the published video stream is banned/unbanned.
///
/// [banned]: Video stream sending status.
/// + true: Video stream is banned.
/// + false: Video stream is unbanned.
typedef OnVideoStreamBannedType = void Function(String uid, bool banned);

/// [uid]: ID of the user of whom the published audio stream is banned/unbanned.
///
/// [banned]: Audio stream sending status.
/// + true: Audio stream is banned.
/// + false: Audio stream is unbanned.
typedef OnAudioStreamBannedType = void Function(String uid, bool banned);

/// [message]: The recognized text message.
typedef OnMessageType = void Function(String message);

/// [errorCode]: Error code
/// + `<0`: Invalid parameter or wrong API call order.
/// + `>0`: Other errors.
///
/// [errorMessage]: Reasons for errors.
typedef OnErrorMsgType = void Function(int errorCode, String errorMessage);

/// [result]: Face detection results.
typedef OnFaceDetectResultType = void Function(FaceDetectionResult result);

/// [uid]: ID of the remote user who publishes the stream.
///
/// [type]: Media stream type.
typedef OnUserPublishStreamType = void Function(
    String uid, MediaStreamType type);

/// [uid]: ID of the user whose stream is removed.
///
/// [type]: Removed stream type.
///
/// [reason]: Reasons for removal of the remote stream.
typedef OnUserUnpublishStreamType = void Function(
    String uid, MediaStreamType type, StreamRemoveReason reason);

/// [deviceId]: Device ID
///
/// [deviceType]: Device type
///
/// [deviceState]: Device status
///
/// [deviceError]: Device related error
typedef OnAudioDeviceStateChangedType = void Function(
    String deviceId,
    AudioDeviceType deviceType,
    MediaDeviceState deviceState,
    MediaDeviceError deviceError);

/// [deviceId]: Device ID
///
/// [deviceType]: Device type
///
/// [deviceState]: Device status
///
/// [deviceError]: Device related error
typedef OnVideoDeviceStateChangedType = void Function(
    String deviceId,
    VideoDeviceType deviceType,
    MediaDeviceState deviceState,
    MediaDeviceError deviceError);

/// [deviceId]: Device ID
///
/// [deviceType]: Device type
///
/// [deviceError]: Device related warning code
typedef OnAudioDeviceWarningType = void Function(String deviceId,
    AudioDeviceType deviceType, MediaDeviceWarning deviceWarning);

/// [deviceId]: Device ID
///
/// [deviceType]: Device type
///
/// [deviceError]: Device related warning code
typedef OnVideoDeviceWarningType = void Function(String deviceId,
    VideoDeviceType deviceType, MediaDeviceWarning deviceWarning);

/// [route]: New audio playback routing
typedef OnAudioRouteChangedType = void Function(AudioRoute route);

/// [roomId]: ID of the room where the ActiveSpeaker stays
///
/// [uid]: ID of the ActiveSpeaker
typedef OnActiveSpeakerType = void Function(String roomId, String uid);

/// @nodoc
@protected
typedef OnStreamSubscribedType = void Function(
    SubscribeState stateCode, String uid, SubscribeConfig info);

/// [type]: Indicating the network is uplink or downlink.
///
/// [quality]: Quality of the network.
///
/// [rtt]: Round-trip time of the network in ms.
///
/// [lostRate]Packet loss rate of the network.
///
/// [bitrate]: Bandwidth of the network in kbps.
///
/// [jitter]: Jitter of the network in ms.
typedef OnNetworkDetectionResultType = Function(NetworkDetectionLinkType type,
    NetworkQuality quality, int rtt, double lostRate, int bitrate, int jitter);

/// [reason]: Reason for stopping detection.
typedef OnNetworkDetectionStoppedType = Function(
    NetworkDetectionStopReason reason);

/// [stateInfos]: List of target room information.
typedef OnForwardStreamStateChangedType = Function(
    List<ForwardStreamStateInfo> stateInfos);

/// [eventInfos]: List of target room events.
typedef OnForwardStreamEventType = Function(
    List<ForwardStreamEventInfo> eventInfos);

/// [localQuality]: Local network quality.
///
/// [remoteQualities]: Network quality of subscribed users.
typedef OnNetworkQualityType = Function(NetworkQualityStats localQuality,
    List<NetworkQualityStats> remoteQualities);

/// [roomId]: ID of the room where the public stream is published.
///
/// [publicStreamId]: Public stream ID.
///
/// [errorCode]: Publishing result, `200` represent success.
typedef OnPushPublicStreamResultType = Function(
    String roomId, String publicStreamId, int errorCode);

/// [publicStreamId]: Public stream ID.
///
/// [errorCode]: Subscribing result.
typedef OnPlayPublicStreamResultType = Function(
    String publicStreamId, int errorCode);

/// [publicStreamId]: Public stream ID.
///
/// [message]: Content of the received SEI message.
typedef OnPublicStreamSEIMessageReceivedType = Function(
    String publicStreamId, Uint8List message);

/// [publicStreamId]: Public stream ID.
///
/// [videoFrameInfo]: Video frame information.
typedef OnFirstPublicStreamVideoFrameDecodedType = Function(
    String publicStreamId, VideoFrameInfo videoFrameInfo);

/// [publicStreamId]: Public stream ID.
typedef OnFirstPublicStreamAudioFrameType = Function(String publicStreamId);

/// [state]: A/V synchronization status.
typedef OnAVSyncStateChangeType = Function(AVSyncState state);

/// [rangeAudioInfo]: Array containing information about the range audio stream.
typedef OnRangeAudioInfoType = Function(List<RangeAudioInfo> rangeAudioInfo);

/// [interval]: Time elapsed from enabling the cloud proxy to successful connection, in ms.
typedef OnCloudProxyConnectedType = Function(int interval);

/// [result]: Detection result.
typedef OnEchoTestResultType = void Function(EchoTestResult result);

/// [eventType]: Task status
///
/// [taskId]: Task ID
///
/// [error]: Error code
typedef OnStreamPushEventType = void Function(
    StreamSinglePushEvent eventType, String taskId, int error);

==> byteplus_rtc-3.45.1.tar.gz: lib/api/bytertc_event_define.dart <==
// Copyright 2022 BytePlus Pte. Ltd.
// SPDX-License-Identifier: MIT

import 'dart:typed_data';

import 'package:flutter/foundation.dart';

import 'bytertc_audio_defines.dart';
import 'bytertc_common_defines.dart';
import 'bytertc_video_defines.dart';

typedef EmptyCallbackType = void Function();

/// [code]: Warning code.
typedef OnWarningType = void Function(WarningCode code);

/// [code]: Error code.
typedef OnErrorType = void Function(ErrorCode code);

/// [roomId]: The ID of the room where the error occurred.
///
/// [errorCode]: Possible errors when creating a room.
typedef OnCreateRoomStateChangedType = void Function(
    String roomId, int errorCode);

/// [state]: Current connection status between SDK and signaling server.
typedef OnConnectionStateChanged = void Function(RTCConnectionState state);

/// [streamIndex]: Stream type.
///
/// [videoFrameInfo]: Video information.
typedef OnFirstLocalVideoFrameCapturedType = void Function(
    StreamIndex streamIndex, VideoFrameInfo videoFrameInfo);

/// [index]: Type of the audio stream.
typedef OnFirstLocalAudioFrameType = void Function(StreamIndex index);

/// [streamKey]: Information about the remote audio stream.
typedef OnFirstRemoteAudioFrameType = void Function(RemoteStreamKey streamKey);

/// [streamKey]: Information about the remote stream.
///
/// [videoFrameInfo]: Information about the video frame.
typedef OnFirstRemoteVideoFrameRenderedType = void Function(
    RemoteStreamKey streamKey, VideoFrameInfo videoFrameInfo);

/// [roomId]: The ID of the room where the remote user who enables/disables media capturing is in.
///
/// [uid]: The ID of the remote user who enables/disables media capturing.
typedef OnUserOperateMediaCaptureType = void Function(
    String roomId, String uid);

/// [audioPropertiesInfos]: Local audio information.
typedef OnLocalAudioPropertiesReportType = void Function(
    List<LocalAudioPropertiesInfo> audioPropertiesInfos);

/// [audioPropertiesInfos]: Remote audio information.
///
/// [totalRemoteVolume]: Total volume of all subscribed remote streams.
typedef OnRemoteAudioPropertiesReportType = void Function(
    List<RemoteAudioPropertiesInfo> audioPropertiesInfos,
    int totalRemoteVolume);

/// [mixId]: Audio mixing task ID.
///
/// [state]: Mixing status.
///
/// [error]: Mixing related error code.
typedef OnAudioMixingStateChangedType = void Function(
    int mixId, AudioMixingState state, AudioMixingError error);

/// [mixId]: Audio mixing task ID.
///
/// [progress]: The current playback progress of the mixed audio file, in milliseconds.
typedef OnAudioMixingPlayingProgressType = void Function(
    int mixId, int progress);

/// [type]: Current network connection type.
typedef OnNetworkTypeChangedType = void Function(NetworkType type);

/// [streamKey]: Including the SEI sender's username, room name and media stream.
///
/// [message]: Content of the SEI message received.
typedef OnSEIMessageReceivedType = void Function(
    RemoteStreamKey streamKey, Uint8List message);

/// [streamKey]: Remote stream information.
///
/// [event]: Status of the black frame video stream.
typedef OnSEIStreamUpdateType = void Function(
    RemoteStreamKey streamKey, SEIStreamUpdateEvent event);

/// [streamKey]: Remote stream information.
///
/// [streamType]: Media stream type.
///
/// [data]: Message content.
typedef OnStreamSyncInfoReceivedType = void Function(
    RemoteStreamKey streamKey, SyncInfoStreamType streamType, Uint8List data);

/// [mode]: Indicates whether publish fallback is enabled locally.
///
/// [roomId]: When publish performance fallback is disabled, roomId is empty. When publish performance fallback is enabled, roomId is the ID of the room affected by the alert.
///
/// [reason]: Reasons for the warning.
///
/// [data]: Performance fallback related data
typedef OnPerformanceAlarmsType = void Function(PerformanceAlarmMode mode,
    String roomId, PerformanceAlarmReason reason, SourceWantedData data);

/// [event]: Information on changes in audio and video streams.
typedef OnSimulcastSubscribeFallbackType = void Function(
    RemoteStreamSwitch event);

/// [state]: Current HTTP proxy connection status.
typedef OnHttpProxyStateType = void Function(int state);

/// [state]: Current HTTPS proxy connection status.
typedef OnHttpsProxyStateType = void Function(int state);

/// [state]: Current SOCKS5 proxy connection status.
typedef OnSocks5ProxyStateType = void Function(int state, String cmd,
    String proxyAddress, String localAddress, String remoteAddress);

/// [type]: Types of recorded streams.
///
/// [state]: Recording status.
///
/// [errorCode]: Recording error code.
///
/// [info]: Details of the recorded file.
typedef OnRecordingStateUpdateType = void Function(StreamIndex type,
    RecordingState state, RecordingErrorCode errorCode, RecordingInfo info);

/// [type]: Types of recorded streams.
///
/// [progress]: Recording progress.
///
/// [info]: Details of the recorded file.
typedef OnRecordingProgressUpdateType = void Function(
    StreamIndex type, RecordingProgress progress, RecordingInfo info);

/// [stats]: CPU and memory information.
typedef OnSysStatsType = void Function(SysStats stats);

/// [stats]: Summary statistics in the room.
typedef OnRoomStatsType = void Function(RTCRoomStats stats);

/// [stats]: Media stream and network status statistics
typedef OnLocalStreamStatsType = void Function(LocalStreamStats stats);

/// [stats]: Media stream and network status statistics
typedef OnRemoteStreamStatsType = void Function(RemoteStreamStats stats);

/// [roomId]: ID of the room where the status change occured.
///
/// [uid]: ID of the user whose status has changed.
///
/// [state]: Room status code:
/// + 0: Success
/// + !0: Failure, see [ErrorCode] and [WarningCode] for details.
///
/// [extraInfo]: Extra information.
/// + `joinType`: `0` represents joining in the room for the first time, `1` represents a reconnection into the room.
/// + `elapsed`: The time interval (in ms) between the local user calling [RTCRoom.joinRoom] and successfully entering the room.
typedef OnRoomStateChangedType = void Function(
    String roomId, String uid, int state, String extraInfo);

/// [stats]: Statistics of this call.
typedef OnLeaveRoomType = void Function(RTCRoomStats stats);

/// [userInfo]: User information.
///
/// [elapsed]: The time in ms between the visible user calling [RTCRoom.joinRoom] to join the room and other users in the room receiving this event.
typedef OnUserJoinedType = void Function(UserInfo userInfo, int elapsed);

/// [uid]: ID of the remote user who left the room or switched to invisible.
///
/// [reason]: Reasons why remote users leave.
typedef OnUserLeaveType = void Function(String uid, UserOfflineReason reason);

/// [eventType]: Task status.
///
/// [taskId]: Task ID.
///
/// [error]: Errors occuring when pushing stream to CDN.
///
/// [mixType]: Task type.
typedef OnStreamMixingEventType = void Function(StreamMixingEvent eventType,
    String taskId, TranscoderErrorCode error, StreamMixingType mixType);

/// [roomId]: ID of the room from which the stream is published.
///
/// [userInfo]: User information.
///
/// [state]: First frame sent status.
typedef OnMediaFrameSendStateChangedType = void Function(
    String roomId, UserInfo userInfo, FirstFrameSendState state);

/// [roomId]: ID of the room which the stream publisher is in.
///
/// [userInfo]: User information.
///
/// [state]: First frame playback status.
typedef OnMediaFramePlayStateChangedType = void Function(
    String roomId, UserInfo userInfo, FirstFramePlayState state);

/// [streamIndex]: Stream type.
///
/// [videoFrameInfo]: Video frame information.
typedef OnLocalVideoSizeChangedType = void Function(
    StreamIndex streamIndex, VideoFrameInfo videoFrameInfo);

/// [streamKey]: Remote stream information.
///
/// [videoFrameInfo]: Video frame information.
typedef OnRemoteVideoSizeChangedType = void Function(
    RemoteStreamKey streamKey, VideoFrameInfo videoFrameInfo);

/// [state]: Status of local audio device.
///
/// [error]: Error code when the state of the local audio stream changes.
typedef OnLocalAudioStateChangedType = void Function(
    LocalAudioStreamState state, LocalAudioStreamError error);

/// [streamKey]: Remote stream information.
///
/// [state]: Remote audio stream status.
///
/// [reason]: Reasons for change in remote audio stream status.
typedef OnRemoteAudioStateChangedType = void Function(RemoteStreamKey streamKey,
    RemoteAudioState state, RemoteAudioStateChangeReason reason);

/// [index]: Stream type.
///
/// [state]: Local video stream status.
///
/// [error]: Error code when local video status changes.
typedef OnLocalVideoStateChangedType = void Function(StreamIndex index,
    LocalVideoStreamState state, LocalVideoStreamError error);

/// [streamKey]: Information about the remote video stream.
///
/// [state]: Remote video stream status.
///
/// [reason]: The reason for the change in the status of the remote video stream.
typedef OnRemoteVideoStateChangedType = void Function(RemoteStreamKey streamKey,
    RemoteVideoState state, RemoteVideoStateChangedReason reason);

/// [uid]: ID of the logged-in user.
///
/// [errorCode]: Login result.
///
/// [elapsed]: The time taken from calling [RTCVideo.login] to the result being returned.
typedef OnLoginResultType = void Function(
    String uid, LoginErrorCode errorCode, int elapsed);

/// [error]: Setting result
/// + 200: Success.
/// + Others: Failure, see [UserMessageSendResult] for details.
typedef OnServerParamsSetResultType = void Function(int error);

/// [peerUid]: ID of the user to be queried.
///
/// [status]: Login status of the queried user.
typedef OnGetPeerOnlineStatusType = void Function(
    String peerUid, UserOnlineStatus status);

/// [msgid]: ID of this message.
///
/// [error]: Text or binary message sending results.
typedef OnMessageSendResultType = void Function(
    int msgid, UserMessageSendResult error);

/// [msgid]: ID of this message.
///
/// [error]: Text or binary message sending results.
typedef OnRoomMessageSendResultType = void Function(
    int msgid, RoomMessageSendResult error);

/// [msgid]: ID of this message.
///
/// [error]: Sending result.
///
/// [message]: Information returned by the application server in the ACK after receiving an HTTP request.
typedef OnServerMessageSendResultType = void Function(
    int msgid, UserMessageSendResult error, Uint8List message);

/// [uid]: ID of the user who send the message.
///
/// [message]: Contents of the received message.
typedef OnMessageReceivedType = void Function(String uid, String message);

/// [uid]: ID of the user who send the message. ID
///
/// [message]: Contents of the received message.
typedef OnBinaryMessageReceivedType = void Function(
    String uid, Uint8List message);

/// [uid]: ID of the user of whom the published video stream is banned/unbanned.
///
/// [banned]: Video stream sending status.
/// + true: Video stream is banned.
/// + false: Video stream is unbanned.
typedef OnVideoStreamBannedType = void Function(String uid, bool banned);

/// [uid]: ID of the user of whom the published audio stream is banned/unbanned.
///
/// [banned]: Audio stream sending status.
/// + true: Audio stream is banned.
/// + false: Audio stream is unbanned.
typedef OnAudioStreamBannedType = void Function(String uid, bool banned);

/// [message]: The recognized text message.
typedef OnMessageType = void Function(String message);

/// [errorCode]: Error code
/// + `<0`: Invalid parameter or wrong API call order.
/// + `>0`: Other errors.
///
/// [errorMessage]: Reasons for errors.
typedef OnErrorMsgType = void Function(int errorCode, String errorMessage);

/// [result]: Face detection results.
typedef OnFaceDetectResultType = void Function(FaceDetectionResult result);

/// [uid]: ID of the remote user who publishes the stream.
///
/// [type]: Media stream type.
typedef OnUserPublishStreamType = void Function(
    String uid, MediaStreamType type);

/// [uid]: ID of the user whose stream is removed.
///
/// [type]: Removed stream type.
///
/// [reason]: Reasons for removal of the remote stream.
typedef OnUserUnpublishStreamType = void Function(
    String uid, MediaStreamType type, StreamRemoveReason reason);

/// [deviceId]: Device ID
///
/// [deviceType]: Device type
///
/// [deviceState]: Device status
///
/// [deviceError]: Device related error
typedef OnAudioDeviceStateChangedType = void Function(
    String deviceId,
    AudioDeviceType deviceType,
    MediaDeviceState deviceState,
    MediaDeviceError deviceError);

/// [deviceId]: Device ID
///
/// [deviceType]: Device type
///
/// [deviceState]: Device status
///
/// [deviceError]: Device related error
typedef OnVideoDeviceStateChangedType = void Function(
    String deviceId,
    VideoDeviceType deviceType,
    MediaDeviceState deviceState,
    MediaDeviceError deviceError);

/// [deviceId]: Device ID
///
/// [deviceType]: Device type
///
/// [deviceError]: Device related warning code
typedef OnAudioDeviceWarningType = void Function(String deviceId,
    AudioDeviceType deviceType, MediaDeviceWarning deviceWarning);

/// [deviceId]: Device ID
///
/// [deviceType]: Device type
///
/// [deviceError]: Device related warning code
typedef OnVideoDeviceWarningType = void Function(String deviceId,
    VideoDeviceType deviceType, MediaDeviceWarning deviceWarning);

/// [route]: New audio playback routing
typedef OnAudioRouteChangedType = void Function(AudioRoute route);

/// [roomId]: ID of the room where the ActiveSpeaker stays
///
/// [uid]: ID of the ActiveSpeaker
typedef OnActiveSpeakerType = void Function(String roomId, String uid);

/// @nodoc
@protected
typedef OnStreamSubscribedType = void Function(
    SubscribeState stateCode, String uid, SubscribeConfig info);

/// [type]: Indicating the network is uplink or downlink.
///
/// [quality]: Quality of the network.
///
/// [rtt]: Round-trip time of the network in ms.
///
/// [lostRate]Packet loss rate of the network.
///
/// [bitrate]: Bandwidth of the network in kbps.
///
/// [jitter]: Jitter of the network in ms.
typedef OnNetworkDetectionResultType = Function(NetworkDetectionLinkType type,
    NetworkQuality quality, int rtt, double lostRate, int bitrate, int jitter);

/// [reason]: Reason for stopping detection.
typedef OnNetworkDetectionStoppedType = Function(
    NetworkDetectionStopReason reason);

/// [stateInfos]: List of target room information.
typedef OnForwardStreamStateChangedType = Function(
    List<ForwardStreamStateInfo> stateInfos);

/// [eventInfos]: List of target room events.
typedef OnForwardStreamEventType = Function(
    List<ForwardStreamEventInfo> eventInfos);

/// [localQuality]: Local network quality.
///
/// [remoteQualities]: Network quality of subscribed users.
typedef OnNetworkQualityType = Function(NetworkQualityStats localQuality,
    List<NetworkQualityStats> remoteQualities);

/// [roomId]: ID of the room where the public stream is published.
///
/// [publicStreamId]: Public stream ID.
///
/// [errorCode]: Publishing result, `200` represent success.
typedef OnPushPublicStreamResultType = Function(
    String roomId, String publicStreamId, PublicStreamErrorCode errorCode);

/// [publicStreamId]: Public stream ID.
///
/// [errorCode]: Subscribing result.
typedef OnPlayPublicStreamResultType = Function(
    String publicStreamId, PublicStreamErrorCode errorCode);

/// [publicStreamId]: Public stream ID.
///
/// [message]: Content of the received SEI message.
typedef OnPublicStreamSEIMessageReceivedType = Function(
    String publicStreamId, Uint8List message);

/// [publicStreamId]: Public stream ID.
///
/// [videoFrameInfo]: Video frame information.
typedef OnFirstPublicStreamVideoFrameDecodedType = Function(
    String publicStreamId, VideoFrameInfo videoFrameInfo);

/// [publicStreamId]: Public stream ID.
typedef OnFirstPublicStreamAudioFrameType = Function(String publicStreamId);

/// [state]: A/V synchronization status.
typedef OnAVSyncStateChangeType = Function(AVSyncState state);

/// [rangeAudioInfo]: Array containing information about the range audio stream.
typedef OnRangeAudioInfoType = Function(List<RangeAudioInfo> rangeAudioInfo);

/// [interval]: Time elapsed from enabling the cloud proxy to successful connection, in ms.
typedef OnCloudProxyConnectedType = Function(int interval);

/// [result]: Detection result.
typedef OnEchoTestResultType = void Function(EchoTestResult result);

/// [eventType]: Task status
///
/// [taskId]: Task ID
///
/// [error]: Error code
typedef OnStreamPushEventType = void Function(
    StreamSinglePushEvent eventType, String taskId, int error);
